==> goods-center-api-2.4.14-SNAPSHOT-fxr-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/AppItemSkuDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import java.util.Date;

/**
 * @ClassName: AppItemSkuDto
 * @Description: 商品sku
 * @author: fxr
 * @date: 2018/6/11 下午4:19
 * @version: V1.0.0
 */
public class AppItemSkuDto {
    /**
     * 唯一ID
     */
    private Long id;

    /**
     * 商品ID
     */
    private Long appItemId;

    /**
     * 积分
     */
    private Long credits;

    /**
     * 展示价格
     */
    private Long facePrice;

    /**
     * 兑换价格
     */
    private Long salePrice;

    /**
     * 库存ID
     */
    private Long stockId;

    /**
     * 属性json串，多属性之间用';'分隔，属性值与key之间用‘：‘分隔，比如 属性ID:系统属性值:开发者自定义属性
     */
    private String attributeJson;

    /**
     * sku子图(预留)
     */
    private String imgUrl;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModify;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Long getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Long salePrice) {
        this.salePrice = salePrice;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public String getAttributeJson() {
        return attributeJson;
    }

    public void setAttributeJson(String attributeJson) {
        this.attributeJson = attributeJson;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModify() {
        return gmtModify;
    }

    public void setGmtModify(Date gmtModify) {
        this.gmtModify = gmtModify;
    }
}

==> goods-center-api-2.5.4-SNAPSHOT-fxr-sources.jar: cn/com/duiba/goods/center/api/remoteservice/dto/sku/AppItemSkuDto.java <==
package cn.com.duiba.goods.center.api.remoteservice.dto.sku;

import java.io.Serializable;
import java.util.Date;

/**
 * @ClassName: AppItemSkuDto
 * @Description: 商品sku
 * @author: fxr
 * @date: 2018/6/11 下午4:19
 * @version: V1.0.0
 */
public class AppItemSkuDto implements Serializable {
    /**
     * 唯一ID
     */
    private Long id;

    /**
     * 商品ID
     */
    private Long appItemId;

    /**
     * 积分
     */
    private Long credits;

    /**
     * 展示价格
     */
    private Long facePrice;

    /**
     * 兑换价格
     */
    private Long salePrice;

    /**
     * 库存ID
     */
    private Long stockId;

    /**
     * 属性json串，多属性之间用';'分隔，属性值与key之间用‘：‘分隔，比如 属性ID:系统属性值:开发者自定义属性
     */
    private String attributeJson;

    /**
     * sku子图(预留)
     */
    private String imgUrl;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 修改时间
     */
    private Date gmtModify;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getAppItemId() {
        return appItemId;
    }

    public void setAppItemId(Long appItemId) {
        this.appItemId = appItemId;
    }

    public Long getCredits() {
        return credits;
    }

    public void setCredits(Long credits) {
        this.credits = credits;
    }

    public Long getFacePrice() {
        return facePrice;
    }

    public void setFacePrice(Long facePrice) {
        this.facePrice = facePrice;
    }

    public Long getSalePrice() {
        return salePrice;
    }

    public void setSalePrice(Long salePrice) {
        this.salePrice = salePrice;
    }

    public Long getStockId() {
        return stockId;
    }

    public void setStockId(Long stockId) {
        this.stockId = stockId;
    }

    public String getAttributeJson() {
        return attributeJson;
    }

    public void setAttributeJson(String attributeJson) {
        this.attributeJson = attributeJson;
    }

    public String getImgUrl() {
        return imgUrl;
    }

    public void setImgUrl(String imgUrl) {
        this.imgUrl = imgUrl;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModify() {
        return gmtModify;
    }

    public void setGmtModify(Date gmtModify) {
        this.gmtModify = gmtModify;
    }
}
